==> PyMandel-1.0.0.tar.gz: PyMandel-1.0.0/colormaps/twilight256_colormap.py <==
from numpy import array

'''
Colormap created by make_colormap utility from file twilight256.png
'''
twilight256 = array([ \
[227, 219, 228], [224, 216, 226], [223, 217, 225], [222, 217, 224],
[221, 217, 224], [219, 216, 223], [217, 216, 222], [216, 215, 221],
[214, 214, 220], [212, 214, 219], [210, 213, 218], [207, 212, 217],
[205, 210, 216], [202, 209, 215], [200, 208, 214], [197, 207, 212],
[194, 205, 211], [191, 204, 210], [188, 202, 209], [185, 201, 208],
[182, 199, 207], [178, 197, 205], [175, 196, 204], [172, 194, 204],
[169, 192, 203], [166, 191, 202], [163, 189, 201], [160, 187, 201],
[157, 186, 200], [154, 184, 199], [152, 182, 199], [149, 180, 198],
[146, 179, 198], [144, 177, 197], [141, 175, 197], [138, 173, 196],
[136, 171, 196], [134, 171, 196], [132, 169, 195], [130, 167, 195],
[128, 165, 195], [126, 163, 194], [124, 161, 194], [122, 159, 194],
[120, 157, 193], [118, 155, 193], [116, 154, 193], [115, 152, 192],
[113, 150, 192], [111, 148, 192], [110, 146, 191], [109, 144, 191],
[107, 142, 191], [106, 139, 190], [105, 137, 190], [104, 135, 190],
[103, 133, 189], [102, 131, 189], [101, 129, 189], [100, 127, 188],
[100, 125, 188], [99, 123, 187], [98, 120, 187], [97, 117, 186],
[97, 115, 185], [97, 113, 185], [96, 110, 184], [96, 108, 183],
[96, 106, 183], [95, 104, 182], [95, 101, 181], [95, 99, 180],
[95, 97, 180], [95, 95, 179], [94, 92, 178], [94, 90, 177],
[94, 88, 176], [94, 85, 175], [94, 83, 173], [94, 80, 172],
[94, 78, 171], [94, 76, 170], [93, 73, 168], [93, 71, 167],
[93, 68, 165], [93, 66, 164], [93, 63, 162], [92, 61, 160],
[92, 59, 158], [92, 56, 156], [92, 54, 154], [91, 51, 152],
[91, 49, 150], [90, 47, 148], [90, 44, 145], [89, 42, 143],
[88, 40, 140], [87, 38, 138], [87, 35, 135], [86, 33, 132],
[85, 32, 129], [83, 30, 126], [82, 28, 123], [81, 27, 120],
[80, 25, 116], [78, 24, 113], [76, 22, 108], [74, 21, 104],
[73, 21, 101], [72, 20, 98], [70, 19, 94], [68, 19, 91],
[67, 18, 88], [65, 18, 85], [63, 17, 82], [62, 17, 79],
[60, 17, 76], [58, 16, 73], [57, 16, 71], [56, 16, 68],
[54, 16, 66], [53, 16, 64], [52, 16, 62], [51, 17, 60],
[50, 17, 59], [49, 17, 57], [48, 18, 55], [47, 19, 54],
[47, 19, 54], [49, 18, 54], [50, 17, 55], [51, 17, 55],
[53, 17, 56], [54, 17, 56], [55, 17, 57], [57, 17, 57],
[59, 17, 58], [61, 17, 59], [63, 17, 60], [65, 17, 61],
[67, 18, 62], [69, 18, 63], [72, 18, 64], [74, 19, 65],
[76, 19, 66], [79, 20, 67], [81, 20, 68], [84, 21, 69],
[88, 21, 71], [90, 22, 72], [93, 23, 73], [95, 23, 74],
[98, 24, 75], [101, 25, 75], [103, 25, 76], [106, 26, 77],
[109, 27, 77], [111, 28, 78], [114, 29, 78], [117, 30, 79],
[119, 31, 79], [122, 32, 79], [124, 33, 79], [127, 34, 80],
[129, 35, 80], [131, 37, 80], [134, 38, 80], [136, 40, 80],
[138, 41, 80], [140, 43, 80], [143, 44, 80], [145, 46, 79],
[147, 48, 79], [149, 50, 79], [151, 51, 79], [153, 53, 79],
[154, 55, 79], [156, 57, 79], [158, 59, 79], [160, 61, 79],
[162, 63, 79], [162, 65, 79], [165, 67, 79], [167, 68, 79],
[167, 71, 79], [169, 73, 80], [170, 75, 80], [172, 77, 80],
[173, 79, 80], [175, 82, 81], [176, 85, 81], [178, 87, 82],
[179, 89, 82], [181, 92, 83], [182, 94, 84], [183, 96, 84],
[184, 99, 85], [185, 101, 86], [186, 103, 87], [187, 106, 88],
[188, 108, 89], [189, 111, 90], [190, 113, 91], [191, 115, 93],
[192, 118, 94], [193, 120, 96], [194, 123, 97], [194, 125, 99],
[195, 128, 101], [196, 130, 103], [196, 133, 105], [197, 135, 107],
[198, 138, 109], [198, 140, 111], [199, 142, 113], [199, 145, 116],
[200, 147, 119], [201, 150, 121], [201, 152, 124], [202, 155, 127],
[202, 157, 129], [203, 159, 132], [203, 162, 135], [204, 164, 138],
[204, 167, 141], [205, 169, 144], [206, 171, 148], [206, 174, 151],
[207, 176, 154], [208, 178, 158], [209, 180, 161], [209, 183, 164],
[210, 185, 168], [211, 188, 173], [212, 190, 176], [213, 192, 180],
[214, 194, 183], [215, 196, 187], [216, 198, 190], [217, 200, 193],
[218, 202, 196], [219, 204, 200], [219, 206, 203], [220, 207, 205],
[221, 209, 208], [222, 210, 210], [222, 211, 213], [223, 213, 215],
[223, 214, 217], [224, 214, 219], [224, 215, 221], [225, 216, 222],
[225, 216, 223], [225, 216, 225], [233, 226, 233], [255, 255, 255]])
'''
End of colormap from file twilight256.png
'''

==> PyMandel-1.0.8.tar.gz: PyMandel-1.0.8/colormaps/twilight256_colormap.py <==
from numpy import array

#****************************************************************************************
# 256-level colormap created by make_colormap utility from file twilight256.png
#****************************************************************************************
twilight256 = array([ \
[227, 219, 228], [224, 216, 226], [223, 217, 225], [222, 217, 224],
[221, 217, 224], [219, 216, 223], [217, 216, 222], [216, 215, 221],
[214, 214, 220], [212, 214, 219], [210, 213, 218], [207, 212, 217],
[205, 210, 216], [202, 209, 215], [200, 208, 214], [197, 207, 212],
[194, 205, 211], [191, 204, 210], [188, 202, 209], [185, 201, 208],
[182, 199, 207], [178, 197, 205], [175, 196, 204], [172, 194, 204],
[169, 192, 203], [166, 191, 202], [163, 189, 201], [160, 187, 201],
[157, 186, 200], [154, 184, 199], [152, 182, 199], [149, 180, 198],
[146, 179, 198], [144, 177, 197], [141, 175, 197], [138, 173, 196],
[136, 171, 196], [134, 171, 196], [132, 169, 195], [130, 167, 195],
[128, 165, 195], [126, 163, 194], [124, 161, 194], [122, 159, 194],
[120, 157, 193], [118, 155, 193], [116, 154, 193], [115, 152, 192],
[113, 150, 192], [111, 148, 192], [110, 146, 191], [109, 144, 191],
[107, 142, 191], [106, 139, 190], [105, 137, 190], [104, 135, 190],
[103, 133, 189], [102, 131, 189], [101, 129, 189], [100, 127, 188],
[100, 125, 188], [99, 123, 187], [98, 120, 187], [97, 117, 186],
[97, 115, 185], [97, 113, 185], [96, 110, 184], [96, 108, 183],
[96, 106, 183], [95, 104, 182], [95, 101, 181], [95, 99, 180],
[95, 97, 180], [95, 95, 179], [94, 92, 178], [94, 90, 177],
[94, 88, 176], [94, 85, 175], [94, 83, 173], [94, 80, 172],
[94, 78, 171], [94, 76, 170], [93, 73, 168], [93, 71, 167],
[93, 68, 165], [93, 66, 164], [93, 63, 162], [92, 61, 160],
[92, 59, 158], [92, 56, 156], [92, 54, 154], [91, 51, 152],
[91, 49, 150], [90, 47, 148], [90, 44, 145], [89, 42, 143],
[88, 40, 140], [87, 38, 138], [87, 35, 135], [86, 33, 132],
[85, 32, 129], [83, 30, 126], [82, 28, 123], [81, 27, 120],
[80, 25, 116], [78, 24, 113], [76, 22, 108], [74, 21, 104],
[73, 21, 101], [72, 20, 98], [70, 19, 94], [68, 19, 91],
[67, 18, 88], [65, 18, 85], [63, 17, 82], [62, 17, 79],
[60, 17, 76], [58, 16, 73], [57, 16, 71], [56, 16, 68],
[54, 16, 66], [53, 16, 64], [52, 16, 62], [51, 17, 60],
[50, 17, 59], [49, 17, 57], [48, 18, 55], [47, 19, 54],
[47, 19, 54], [49, 18, 54], [50, 17, 55], [51, 17, 55],
[53, 17, 56], [54, 17, 56], [55, 17, 57], [57, 17, 57],
[59, 17, 58], [61, 17, 59], [63, 17, 60], [65, 17, 61],
[67, 18, 62], [69, 18, 63], [72, 18, 64], [74, 19, 65],
[76, 19, 66], [79, 20, 67], [81, 20, 68], [84, 21, 69],
[88, 21, 71], [90, 22, 72], [93, 23, 73], [95, 23, 74],
[98, 24, 75], [101, 25, 75], [103, 25, 76], [106, 26, 77],
[109, 27, 77], [111, 28, 78], [114, 29, 78], [117, 30, 79],
[119, 31, 79], [122, 32, 79], [124, 33, 79], [127, 34, 80],
[129, 35, 80], [131, 37, 80], [134, 38, 80], [136, 40, 80],
[138, 41, 80], [140, 43, 80], [143, 44, 80], [145, 46, 79],
[147, 48, 79], [149, 50, 79], [151, 51, 79], [153, 53, 79],
[154, 55, 79], [156, 57, 79], [158, 59, 79], [160, 61, 79],
[162, 63, 79], [162, 65, 79], [165, 67, 79], [167, 68, 79],
[167, 71, 79], [169, 73, 80], [170, 75, 80], [172, 77, 80],
[173, 79, 80], [175, 82, 81], [176, 85, 81], [178, 87, 82],
[179, 89, 82], [181, 92, 83], [182, 94, 84], [183, 96, 84],
[184, 99, 85], [185, 101, 86], [186, 103, 87], [187, 106, 88],
[188, 108, 89], [189, 111, 90], [190, 113, 91], [191, 115, 93],
[192, 118, 94], [193, 120, 96], [194, 123, 97], [194, 125, 99],
[195, 128, 101], [196, 130, 103], [196, 133, 105], [197, 135, 107],
[198, 138, 109], [198, 140, 111], [199, 142, 113], [199, 145, 116],
[200, 147, 119], [201, 150, 121], [201, 152, 124], [202, 155, 127],
[202, 157, 129], [203, 159, 132], [203, 162, 135], [204, 164, 138],
[204, 167, 141], [205, 169, 144], [206, 171, 148], [206, 174, 151],
[207, 176, 154], [208, 178, 158], [209, 180, 161], [209, 183, 164],
[210, 185, 168], [211, 188, 173], [212, 190, 176], [213, 192, 180],
[214, 194, 183], [215, 196, 187], [216, 198, 190], [217, 200, 193],
[218, 202, 196], [219, 204, 200], [219, 206, 203], [220, 207, 205],
[221, 209, 208], [222, 210, 210], [222, 211, 213], [223, 213, 215],
[223, 214, 217], [224, 214, 219], [224, 215, 221], [225, 216, 222],
[225, 216, 223], [225, 216, 225], [233, 226, 233], [255, 255, 255]])
